==> openshift-model-5.7.4-sources.jar: io/fabric8/openshift/api/model/LDAPAttributeMappingFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LDAPAttributeMappingFluent<A extends io.fabric8.openshift.api.model.LDAPAttributeMappingFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToEmail(java.lang.Integer index,java.lang.String item);
  public A setToEmail(java.lang.Integer index,java.lang.String item);
  public A addToEmail(java.lang.String... items);
  public A addAllToEmail(java.util.Collection<java.lang.String> items);
  public A removeFromEmail(java.lang.String... items);
  public A removeAllFromEmail(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getEmail();
  public java.lang.String getEmail(java.lang.Integer index);
  public java.lang.String getFirstEmail();
  public java.lang.String getLastEmail();
  public java.lang.String getMatchingEmail(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingEmail(java.util.function.Predicate<java.lang.String> predicate);
  public A withEmail(java.util.List<java.lang.String> email);
  public A withEmail(java.lang.String... email);
  public java.lang.Boolean hasEmail();
  public A addNewEmail(java.lang.String arg0);
  public A addToId(java.lang.Integer index,java.lang.String item);
  public A setToId(java.lang.Integer index,java.lang.String item);
  public A addToId(java.lang.String... items);
  public A addAllToId(java.util.Collection<java.lang.String> items);
  public A removeFromId(java.lang.String... items);
  public A removeAllFromId(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getId();
  public java.lang.String getId(java.lang.Integer index);
  public java.lang.String getFirstId();
  public java.lang.String getLastId();
  public java.lang.String getMatchingId(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingId(java.util.function.Predicate<java.lang.String> predicate);
  public A withId(java.util.List<java.lang.String> id);
  public A withId(java.lang.String... id);
  public java.lang.Boolean hasId();
  public A addNewId(java.lang.String arg0);
  public A addToName(java.lang.Integer index,java.lang.String item);
  public A setToName(java.lang.Integer index,java.lang.String item);
  public A addToName(java.lang.String... items);
  public A addAllToName(java.util.Collection<java.lang.String> items);
  public A removeFromName(java.lang.String... items);
  public A removeAllFromName(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getName();
  public java.lang.String getName(java.lang.Integer index);
  public java.lang.String getFirstName();
  public java.lang.String getLastName();
  public java.lang.String getMatchingName(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingName(java.util.function.Predicate<java.lang.String> predicate);
  public A withName(java.util.List<java.lang.String> name);
  public A withName(java.lang.String... name);
  public java.lang.Boolean hasName();
  public A addNewName(java.lang.String arg0);
  public A addToPreferredUsername(java.lang.Integer index,java.lang.String item);
  public A setToPreferredUsername(java.lang.Integer index,java.lang.String item);
  public A addToPreferredUsername(java.lang.String... items);
  public A addAllToPreferredUsername(java.util.Collection<java.lang.String> items);
  public A removeFromPreferredUsername(java.lang.String... items);
  public A removeAllFromPreferredUsername(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getPreferredUsername();
  public java.lang.String getPreferredUsername(java.lang.Integer index);
  public java.lang.String getFirstPreferredUsername();
  public java.lang.String getLastPreferredUsername();
  public java.lang.String getMatchingPreferredUsername(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingPreferredUsername(java.util.function.Predicate<java.lang.String> predicate);
  public A withPreferredUsername(java.util.List<java.lang.String> preferredUsername);
  public A withPreferredUsername(java.lang.String... preferredUsername);
  public java.lang.Boolean hasPreferredUsername();
  public A addNewPreferredUsername(java.lang.String arg0);
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/LDAPAttributeMappingFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface LDAPAttributeMappingFluent<A extends io.fabric8.openshift.api.model.LDAPAttributeMappingFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToEmail(java.lang.Integer index,java.lang.String item);
  public A setToEmail(java.lang.Integer index,java.lang.String item);
  public A addToEmail(java.lang.String... items);
  public A addAllToEmail(java.util.Collection<java.lang.String> items);
  public A removeFromEmail(java.lang.String... items);
  public A removeAllFromEmail(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getEmail();
  public java.lang.String getEmail(java.lang.Integer index);
  public java.lang.String getFirstEmail();
  public java.lang.String getLastEmail();
  public java.lang.String getMatchingEmail(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingEmail(java.util.function.Predicate<java.lang.String> predicate);
  public A withEmail(java.util.List<java.lang.String> email);
  public A withEmail(java.lang.String... email);
  public java.lang.Boolean hasEmail();
  public A addNewEmail(java.lang.String arg0);
  public A addToId(java.lang.Integer index,java.lang.String item);
  public A setToId(java.lang.Integer index,java.lang.String item);
  public A addToId(java.lang.String... items);
  public A addAllToId(java.util.Collection<java.lang.String> items);
  public A removeFromId(java.lang.String... items);
  public A removeAllFromId(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getId();
  public java.lang.String getId(java.lang.Integer index);
  public java.lang.String getFirstId();
  public java.lang.String getLastId();
  public java.lang.String getMatchingId(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingId(java.util.function.Predicate<java.lang.String> predicate);
  public A withId(java.util.List<java.lang.String> id);
  public A withId(java.lang.String... id);
  public java.lang.Boolean hasId();
  public A addNewId(java.lang.String arg0);
  public A addToName(java.lang.Integer index,java.lang.String item);
  public A setToName(java.lang.Integer index,java.lang.String item);
  public A addToName(java.lang.String... items);
  public A addAllToName(java.util.Collection<java.lang.String> items);
  public A removeFromName(java.lang.String... items);
  public A removeAllFromName(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getName();
  public java.lang.String getName(java.lang.Integer index);
  public java.lang.String getFirstName();
  public java.lang.String getLastName();
  public java.lang.String getMatchingName(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingName(java.util.function.Predicate<java.lang.String> predicate);
  public A withName(java.util.List<java.lang.String> name);
  public A withName(java.lang.String... name);
  public java.lang.Boolean hasName();
  public A addNewName(java.lang.String arg0);
  public A addToPreferredUsername(java.lang.Integer index,java.lang.String item);
  public A setToPreferredUsername(java.lang.Integer index,java.lang.String item);
  public A addToPreferredUsername(java.lang.String... items);
  public A addAllToPreferredUsername(java.util.Collection<java.lang.String> items);
  public A removeFromPreferredUsername(java.lang.String... items);
  public A removeAllFromPreferredUsername(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getPreferredUsername();
  public java.lang.String getPreferredUsername(java.lang.Integer index);
  public java.lang.String getFirstPreferredUsername();
  public java.lang.String getLastPreferredUsername();
  public java.lang.String getMatchingPreferredUsername(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingPreferredUsername(java.util.function.Predicate<java.lang.String> predicate);
  public A withPreferredUsername(java.util.List<java.lang.String> preferredUsername);
  public A withPreferredUsername(java.lang.String... preferredUsername);
  public java.lang.Boolean hasPreferredUsername();
  public A addNewPreferredUsername(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
